@@ -74,8 +74,8 @@ def get_db_version(db_file: os.PathLike) -> str:
     conn.close()
 
     if version not in _TESTED_DB_VERSIONS:
-        print(
-            f"WARNING: Only tested on database versions [{', '.join(_TESTED_DB_VERSIONS)}]"
+        logger.warning(
+            f"WARNING: OSXPhotos has only been tested on Photos database versions [{', '.join(_TESTED_DB_VERSIONS)}]"
             + f" You have database version={version} which has not been tested",
             file=sys.stderr,
         )
@@ -166,19 +166,29 @@ def get_photos_library_version(library_path: str | pathlib.Path) -> int:
     Returns: int of major Photos version number (e.g. 5, 6, ...)
     """
     library_path = pathlib.Path(library_path)
-    if library_path.is_dir():
-        library_path = library_path / "database" / "photos.db"
-    db_ver = int(get_db_version(str(library_path)))
-    if db_ver == int(_PHOTOS_2_VERSION):
-        return 2
-    if db_ver == int(_PHOTOS_3_VERSION):
-        return 3
-    if db_ver == int(_PHOTOS_4_VERSION):
-        return 4
+    if not library_path.is_dir():
+        # assume we got passed library path/database/Photos.sqlite or library path/database/photos.db
+        library_path = library_path.parent.parent
+
+    db_path = library_path / "database" / "photos.db"
+    if db_path.exists():
+        try:
+            db_ver = int(get_db_version(str(db_path)))
+            if db_ver == int(_PHOTOS_2_VERSION):
+                return 2
+            if db_ver == int(_PHOTOS_3_VERSION):
+                return 3
+            if db_ver == int(_PHOTOS_4_VERSION):
+                return 4
+        except Exception:
+            pass
 
     # assume it's a Photos 5+ library, get the model version to determine which version
-    library_path = library_path.parent / "Photos.sqlite"
-    return get_photos_version_from_model(str(library_path))
+    db_path = library_path / "database" / "Photos.sqlite"
+    if db_path.exists():
+        return get_photos_version_from_model(str(db_path))
+    else:
+        raise ValueError(f"Could not find Photos database at: {library_path}")
 
 
 def get_db_path_for_library(photos_library: str | pathlib.Path) -> pathlib.Path:
